# qualysclient 
[![qualysclient Actions Status](https://img.shields.io/github/workflow/status/woodtechie1428/qualysclient/Publish%20Python%20%F0%9F%90%8D%20distributions%20%F0%9F%93%A6%20to%20PyPI?style=plastic)](https://github.com/woodtechie1428/qualysclient/actions)
[![qualysclient Actions Status](https://img.shields.io/github/license/woodtechie1428/qualysclient?style=plastic)](https://github.com/woodtechie1428/qualysclient/blob/main/LICENSE)
[![qualysclient Actions Status](https://img.shields.io/readthedocs/qualysclient?style=plastic)](https://qualysclient.readthedocs.io/en/latest/)
[![qualysclient Downlaods](https://img.shields.io/pypi/dm/qualysclient?logo=PyPi&style=plastic)](https://pypi.org/project/qualysclient/)
[![qualysclient version](https://img.shields.io/github/v/release/woodtechie1428/qualysclient?sort=semver&style=plastic)](https://github.com/woodtechie1428/qualysclient/releases)
[![release date](https://img.shields.io/github/release-date/woodtechie1428/qualysclient?style=plastic)](https://github.com/woodtechie1428/qualysclient/releases)


A python SDK for interacting with the Qualys API

## Installation
```
python -m pip install qualysclient
```

## Example 

```
import qualysclient

```
